==> java-cxf-spring-server-generator-0.13.2.tgz: package/test-output/junit5/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/SearchResults.java <==
package com.example.model;

/**
 * Model for SearchResults
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-05T19:55:16.329Z")
@io.swagger.annotations.ApiModel(value = "SearchResults", description = "Model for SearchResults")
@javax.xml.bind.annotation.XmlRootElement(name = "SearchResults")
public class SearchResults implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private java.util.List<com.example.model.Components> fraudassessment = new java.util.ArrayList<com.example.model.Components>();
	private java.util.List<com.example.model.Verification> verification = null;
	
	/**
	 */
	public SearchResults fraudassessment(java.util.List<com.example.model.Components> fraudassessment) {
		setFraudassessment(fraudassessment);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(required = true, value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("fraudassessment")
	@javax.validation.Valid
	@javax.validation.constraints.NotNull
	public java.util.List<com.example.model.Components> getFraudassessment() {
		return this.fraudassessment;
	}
	public void setFraudassessment(java.util.List<com.example.model.Components> fraudassessment) {
		this.fraudassessment = fraudassessment;
	}
	public SearchResults addFraudassessment(com.example.model.Components fraudassessment) {
		if (this.fraudassessment == null) {
			this.fraudassessment = new java.util.ArrayList<com.example.model.Components>();
		}
		this.fraudassessment.add(fraudassessment);
		return this;
	}
	
	/**
	 */
	public SearchResults verification(java.util.List<com.example.model.Verification> verification) {
		setVerification(verification);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("verification")
	@javax.validation.Valid
	public java.util.List<com.example.model.Verification> getVerification() {
		return this.verification;
	}
	public void setVerification(java.util.List<com.example.model.Verification> verification) {
		this.verification = verification;
	}
	public SearchResults addVerification(com.example.model.Verification verification) {
		if (this.verification == null) {
			this.verification = new java.util.ArrayList<com.example.model.Verification>();
		}
		this.verification.add(verification);
		return this;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		SearchResults searchResults = (SearchResults) o;
		return java.util.Objects.equals(this.fraudassessment, searchResults.fraudassessment)
				&& java.util.Objects.equals(this.verification, searchResults.verification);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.fraudassessment, this.verification);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class SearchResults {\n");
		
		sb.append("    fraudassessment: ").append(toIndentedString(this.fraudassessment)).append("\n");
		sb.append("    verification: ").append(toIndentedString(this.verification)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}

==> java-cxf-spring-server-generator-0.14.0.tgz: package/test-output/junit5/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/SearchResults.java <==
package com.example.model;

/**
 * Model for SearchResults
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-09T22:14:49.443Z")
@io.swagger.v3.oas.annotations.media.Schema(name = "SearchResults", description = "Model for SearchResults")
@javax.xml.bind.annotation.XmlRootElement(name = "SearchResults")
public class SearchResults implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private java.util.List<com.example.model.Components> fraudassessment = new java.util.ArrayList<com.example.model.Components>();
	private java.util.List<com.example.model.Verification> verification = null;
	
	/**
	 */
	public SearchResults fraudassessment(java.util.List<com.example.model.Components> fraudassessment) {
		setFraudassessment(fraudassessment);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(required = true, name = "fraudassessment")
	@com.fasterxml.jackson.annotation.JsonProperty("fraudassessment")
	@javax.validation.Valid
	@javax.validation.constraints.NotNull
	public java.util.List<com.example.model.Components> getFraudassessment() {
		return this.fraudassessment;
	}
	public void setFraudassessment(java.util.List<com.example.model.Components> fraudassessment) {
		this.fraudassessment = fraudassessment;
	}
	public SearchResults addFraudassessment(com.example.model.Components fraudassessment) {
		if (this.fraudassessment == null) {
			this.fraudassessment = new java.util.ArrayList<com.example.model.Components>();
		}
		this.fraudassessment.add(fraudassessment);
		return this;
	}
	
	/**
	 */
	public SearchResults verification(java.util.List<com.example.model.Verification> verification) {
		setVerification(verification);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "verification")
	@com.fasterxml.jackson.annotation.JsonProperty("verification")
	@javax.validation.Valid
	public java.util.List<com.example.model.Verification> getVerification() {
		return this.verification;
	}
	public void setVerification(java.util.List<com.example.model.Verification> verification) {
		this.verification = verification;
	}
	public SearchResults addVerification(com.example.model.Verification verification) {
		if (this.verification == null) {
			this.verification = new java.util.ArrayList<com.example.model.Verification>();
		}
		this.verification.add(verification);
		return this;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		SearchResults searchResults = (SearchResults) o;
		return java.util.Objects.equals(this.fraudassessment, searchResults.fraudassessment)
				&& java.util.Objects.equals(this.verification, searchResults.verification);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.fraudassessment, this.verification);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class SearchResults {\n");
		
		sb.append("    fraudassessment: ").append(toIndentedString(this.fraudassessment)).append("\n");
		sb.append("    verification: ").append(toIndentedString(this.verification)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}
